@@ -2,7 +2,6 @@ package cli
 
 import (
 	"errors"
-	"fmt"
 	"slices"
 	"strings"
 	"time"
@@ -171,14 +170,7 @@ var filteringFlag = []cli.Flag{
 		Category: "FILTERING",
 		Action: func(context *cli.Context, i []string) error {
 			if len(i) > 0 {
-				err := limitOnce.Do(
-					func() error {
-						return setLimit(context)
-					},
-				)
-				if err != nil {
-					return err
-				}
+				setLimit()
 				eft := filter.MimeTypeOnly(i...)
 				itemFilterFunc = append(itemFilterFunc, &eft)
 			}
@@ -197,7 +189,6 @@ var filteringFlag = []cli.Flag{
 				if strings.HasPrefix(f, "+") {
 					t, err := strftime.Parse(s, strings.TrimPrefix(f, "+"))
 					if err != nil {
-						fmt.Println(err)
 						continue
 					}
 					f := filter.BeforeTime(t, filter.WhichTimeFiled(timeType[0]))
@@ -228,6 +219,15 @@ var filteringFlag = []cli.Flag{
 		Action: func(ctx *cli.Context, s string) error {
 			possibleTimeFormat := []string{"01-02", "01-02 15:04", "15:04", "2006-01-02", "2006-01-02 15:04", timeFormat}
 			for _, f := range possibleTimeFormat {
+				if strings.HasPrefix(f, "+") {
+					t, err := strftime.Parse(s, strings.TrimPrefix(f, "+"))
+					if err != nil {
+						continue
+					}
+					f := filter.AfterTime(t, filter.WhichTimeFiled(timeType[0]))
+					itemFilterFunc = append(itemFilterFunc, &f)
+					return nil
+				}
 				t, err := time.ParseInLocation(f, s, time.Local)
 				if err != nil {
 					continue
