@@ -29,10 +29,7 @@ import (
 	"github.com/Equationzhao/g/internal/util"
 	"github.com/Equationzhao/pathbeautify"
 	"github.com/hako/durafmt"
-	"github.com/savioxavier/termlink"
 	"github.com/urfave/cli/v2"
-	"github.com/xrash/smetrics"
-	"go.szostok.io/version/upgrade"
 )
 
 var (
@@ -61,7 +58,6 @@ var (
 	nameToDisplay    = contents.NewNameEnabler()
 	flagsEnabler     = contents.NewFlagsEnabler()
 	depthLimitMap    map[string]int
-	limitOnce        = util.Once{}
 	hookOnce         = util.Once{}
 	duplicateDetect  = contents.NewDuplicateDetect()
 	hookPost         = make([]func(display.Printer, ...*item.FileInfo), 0)
@@ -98,21 +94,6 @@ func init() {
 	}
 	G.Flags = append(
 		G.Flags,
-		&cli.BoolFlag{
-			Name:     "check-new-version",
-			Usage:    "check if there's new release",
-			Category: "\b\b\b   META", // add \b to ensure the category is the first one to show
-			Action: func(context *cli.Context, b bool) error {
-				if b {
-					upgrade.WithUpdateCheckTimeout(5 * time.Second)
-					notice := upgrade.NewGitHubDetector("Equationzhao", "g")
-					_ = notice.PrintIfFoundGreater(os.Stderr, Version)
-					return Err4Exit{}
-				}
-				return nil
-			},
-			DisableDefaultText: true,
-		},
 		&cli.BoolFlag{
 			Name:               "no-path-transform",
 			Aliases:            []string{"np"},
@@ -271,7 +252,6 @@ const optionsHelp = `GLOBAL OPTIONS
    --si                       use powers of 1000 for size format(default: false)
 
 META
-   --check-new-version  check if there's new release
    --help, -h, -?       show help
    --version, -v        print the version
 
@@ -366,8 +346,6 @@ VIEW
                                              md5, sha1, sha224, sha256, sha384, sha512, crc32(default: sha1)
    --create, --cr, --created               created time
    --dereference                           dereference symbolic links
-   --detect-size value                     set exact size for mimetype detection
-                                             eg:1M/nolimit/infinity(default: 1M)
    --extended, -@                          list each file's extended attributes and sizes in long listing
    --footer                                add a footer row
    --fp, --full-path, --fullpath           show full path
@@ -475,7 +453,7 @@ func suggestFlag(flags []cli.Flag, provided string) string {
 	for _, flag := range flags {
 		flagNames := flag.Names()
 		for _, name := range flagNames {
-			newDistance := smetrics.JaroWinkler(name, provided, global.BoostThreshold, global.PrefixSize)
+			newDistance := util.JaroWinkler(name, provided, global.BoostThreshold, global.PrefixSize)
 			if newDistance > distance {
 				distance = newDistance
 				suggestion = name
@@ -624,7 +602,7 @@ var logic = func(context *cli.Context) error {
 	default:
 		fallthrough
 	case "auto":
-		if termlink.SupportsHyperlinks() {
+		if util.SupportsHyperlinks() {
 			switch p.(type) {
 			case display.PrettyPrinter:
 			case *display.JsonPrinter:
