@@ -1,16 +1,14 @@
 package content
 
 import (
+	"runtime"
 	"slices"
 	"sync"
 
 	"github.com/Equationzhao/g/internal/display"
 	"github.com/Equationzhao/g/internal/item"
-	"github.com/panjf2000/ants/v2"
 )
 
-var Pool *ants.Pool
-
 type ContentFilter struct {
 	noOutputOptions []NoOutputOption
 	options         []ContentOption
@@ -90,19 +88,20 @@ func (cf *ContentFilter) GetDisplayItems(e *[]*item.FileInfo) {
 	if cf.LimitN > 0 && len(*e) > int(cf.LimitN) {
 		*e = (*e)[:cf.LimitN]
 	}
+
+	maxGoroutines := 10 * runtime.NumCPU()
+	sem := make(chan struct{}, maxGoroutines)
 	wg := sync.WaitGroup{}
 	wg.Add(len(*e))
+
 	for _, entry := range *e {
 		entry := entry
-		err := Pool.Submit(
-			func() {
-				defer wg.Done()
-				_ = cf.processEntry(entry)
-			},
-		)
-		if err != nil {
-			panic(err)
-		}
+		sem <- struct{}{}
+		go func(e *item.FileInfo) {
+			defer wg.Done()
+			defer func() { <-sem }()
+			_ = cf.processEntry(e)
+		}(entry)
 	}
 	wg.Wait()
 }
