@@ -2,15 +2,15 @@ package man
 
 import (
 	"compress/gzip"
+	"os"
 	"path/filepath"
 
 	"github.com/Equationzhao/g/internal/cli"
-	"github.com/spf13/afero"
 )
 
-func GenMan(fs afero.Fs) {
+func GenMan() {
 	// man
-	man, _ := fs.Create(filepath.Join("man", "g.1.gz"))
+	man, _ := os.Create(filepath.Join("man", "g.1.gz"))
 	s, _ := cli.G.ToMan()
 	// compress to gzip
 	manGz := gzip.NewWriter(man)
